.. _getting_started:

Getting started
===============

.. include:: ../../README.rst
   :start-line: 4

This package is now featured in the collection of
`SciKit libraries <http://scikits.appspot.com/scikits>`_
